Creates a radar-style chart showing prevalence of key risk factors on a polar coordinate system for quick visual comparison.

build_radar_plot(key_indicators, country_name, survey_year)

Arguments

key_indicators

A data frame with domain, indicator, estimate.

country_name

Country name for title.

survey_year

Survey year for title.

Value

A ggplot2 object.